@@ -426,7 +426,7 @@ static int parse_phyint(char *s)
                         continue;
                     }
                 }
-                ph = (struct phaddr *)malloc(sizeof(struct phaddr));
+                ph = (struct phaddr *)calloc(1, sizeof(struct phaddr));
                 if (ph == NULL)
                     return(FALSE);
                 if (altnet_masklen) {
@@ -473,7 +473,7 @@ static int parse_phyint(char *s)
                     }
                 }
 
-                v_acl = (struct vif_acl *)malloc(sizeof(struct vif_acl));
+                v_acl = (struct vif_acl *)calloc(1, sizeof(struct vif_acl));
                 if (v_acl == NULL)
                     return(FALSE);
                 VAL_TO_MASK(v_acl->acl_mask, scoped_masklen);
@@ -767,7 +767,7 @@ int parseBSR(char *s)
  * multicast group addresses as well.
  *
  * Format:
- * rp_address <rp-address>
+ * rp_address <rp-address> [<group-addr> [masklen <masklen>] [priority <number>]]
  *
  * Returns:
  * When parsing @s is successful this function returns %TRUE, otherwise %FALSE.
@@ -776,10 +776,12 @@ int parse_rp_address(char *s)
 {
     char *w;
     u_int32 local = 0xffffff;
-    u_int32 group_addr;
-    u_int32 masklen;
+    u_int32 group_addr = htonl(INADDR_UNSPEC_GROUP);
+    u_int32 masklen = PIM_GROUP_PREFIX_DEFAULT_MASKLEN;
+    u_int priority = PIM_DEFAULT_CAND_RP_PRIORITY;
     struct rp_hold * rph;
 
+    /* next is RP addr */
     w = next_word(&s);
     if (EQUAL(w, "")) {
         logit(LOG_WARNING, 0, "'rp_address' in %s: no <rp-addr> - ignoring", configfilename);
@@ -792,6 +794,7 @@ int parse_rp_address(char *s)
         return FALSE;
     }
 
+    /* next is group addr if exist */
     w = next_word(&s);
     if (!EQUAL(w, "")) {
         group_addr = inet_parse(w, 4);
@@ -800,27 +803,50 @@ int parse_rp_address(char *s)
             return FALSE;
         }
 
-        if (EQUAL((w = next_word(&s)), "masklen")) {
-            w = next_word(&s);
-            if (sscanf(w, "%u", &masklen) == 1) {
-                if (masklen > (sizeof(group_addr) * 8))
-                    masklen = (sizeof(group_addr) * 8);
-                else if (masklen < 4)
-                    masklen = 4;
-            }
-            else
-                masklen = PIM_GROUP_PREFIX_DEFAULT_MASKLEN;
-        }
-        else
-            masklen = PIM_GROUP_PREFIX_DEFAULT_MASKLEN;
+	masklen = PIM_GROUP_PREFIX_DEFAULT_MASKLEN;
+	priority = PIM_DEFAULT_CAND_RP_PRIORITY;
+
+	/* next is prefix or priority if exist */
+	while (!EQUAL((w = next_word(&s)), "")) {
+	    if (EQUAL(w, "masklen")) {
+		w = next_word(&s);
+		if (sscanf(w, "%u", &masklen) == 1) {
+		    if (masklen > (sizeof(group_addr) * 8)) {
+			masklen = (sizeof(group_addr) * 8);
+		    }
+		    else if (masklen < PIM_GROUP_PREFIX_MIN_MASKLEN) {
+			logit(LOG_WARNING, 0, "'rp_address' in %s: %s is too small. set to %d.", configfilename, w, PIM_GROUP_PREFIX_MIN_MASKLEN);
+			masklen = PIM_GROUP_PREFIX_MIN_MASKLEN;
+		    }
+		}
+		else {
+		    logit(LOG_WARNING, 0, "'rp_address' in %s: %s is invalid masklen. set to default(%d)", configfilename, w, PIM_GROUP_PREFIX_DEFAULT_MASKLEN);
+		    masklen = PIM_GROUP_PREFIX_DEFAULT_MASKLEN;
+		}
+	    }
+	    else if (EQUAL(w, "priority")) {
+		w = next_word(&s);
+		if (sscanf(w, "%u", &priority) == 1) {
+		    if (priority > PIM_MAX_CAND_RP_PRIORITY) {
+			logit(LOG_WARNING, 0, "'rp_address' in %s: %s is too big. set to %d.", configfilename, w, PIM_MAX_CAND_RP_PRIORITY);
+			priority = PIM_MAX_CAND_RP_PRIORITY;
+		    }
+		}
+		else {
+		    logit(LOG_WARNING, 0, "'rp_address' in %s: %s is invalid priority. set to default(%d)", configfilename, w, PIM_DEFAULT_CAND_RP_PRIORITY);
+		    priority = PIM_DEFAULT_CAND_RP_PRIORITY;
+		}
+	    }
+	}
     }
     else {
-        group_addr = htonl(224 << 24);
-        masklen = 4;
+        group_addr = htonl(INADDR_UNSPEC_GROUP);
+        masklen = PIM_GROUP_PREFIX_MIN_MASKLEN;
+	priority = 1;
     }
 
     /* save */
-    rph = malloc(sizeof(*rph));
+    rph = calloc(1, sizeof(*rph));
     if (!rph) {
 	logit(LOG_WARNING, 0, "Ran out of memory in parse_rp_address()");
 	return FALSE;
@@ -828,12 +854,13 @@ int parse_rp_address(char *s)
     rph->address = local;
     rph->group = group_addr;
     VAL_TO_MASK(rph->mask, masklen);
+    rph->priority = priority;
 
     /* attach at the beginning */
     rph->next = g_rp_hold;
     g_rp_hold = rph;
 
-    logit(LOG_INFO, 0, "Added static RP: %s, group %s/%d", inet_fmt(local, s1, sizeof(s1)), inet_fmt(group_addr, s2, sizeof(s2)), masklen);
+    logit(LOG_INFO, 0, "Added static RP: %s, group %s/%d, prioriy %d", inet_fmt(local, s1, sizeof(s1)), inet_fmt(group_addr, s2, sizeof(s2)), masklen, priority);
 
     return TRUE;
 }
@@ -1079,7 +1106,7 @@ void config_vifs_from_file(void)
 
     /* TODO: HARDCODING!!! */
     cand_rp_adv_message.buffer =
-        (u_int8 *)malloc(4 + sizeof(pim_encod_uni_addr_t)
+        (u_int8 *)calloc(1, 4 + sizeof(pim_encod_uni_addr_t)
                            + 255 * sizeof(pim_encod_grp_addr_t));
     if (!cand_rp_adv_message.buffer) {
 	logit(LOG_ERR, errno, "Ran out of memory in config_vifs_from_file()");
