@@ -373,11 +373,11 @@ void logit(int severity, int syserr, const char *format, ...)
         if (!debug)
             fprintf(stderr, "%s: ", __progname);
         fprintf(stderr, "%02d:%02d:%02d.%03ld %s", thyme->tm_hour,
-                thyme->tm_min, thyme->tm_sec, now.tv_usec / 1000, msg);
+                thyme->tm_min, thyme->tm_sec, (long int)(now.tv_usec / 1000), msg);
         if (syserr == 0)
             fprintf(stderr, "\n");
-
-        fprintf(stderr, ":(error %d): %s\n", syserr, strerror(syserr));
+	else
+	    fprintf(stderr, ":(error %d): %s\n", syserr, strerror(syserr));
     }
 
     /*
@@ -393,9 +393,10 @@ void logit(int severity, int syserr, const char *format, ...)
             log_nmsgs++;
         if (syserr != 0) {
             errno = syserr;
-            syslog(severity, "%s: %m", msg);
-        } else
+            syslog(severity, "%s: %s", msg, strerror(syserr));
+        } else {
             syslog(severity, "%s", msg);
+	}
     }
 
     if (severity <= LOG_ERR) exit(-1);
