@@ -59,11 +59,15 @@ void k_init_pim(int socket)
 {
     int v = 1;
 
-    if (setsockopt(socket, IPPROTO_IP, MRT_INIT, (char *)&v, sizeof(int)) < 0)
-        logit(LOG_ERR, errno, "cannot enable multicast routing in kernel");
+    if (setsockopt(socket, IPPROTO_IP, MRT_INIT, (char *)&v, sizeof(int)) < 0) {
+	if (errno == EADDRINUSE)
+	    logit(LOG_ERR, 0, "Another multicast routing application is already running.");
+	else
+	    logit(LOG_ERR, errno, "Cannot enable multicast routing in kernel");
+    }
 
     if (setsockopt(socket, IPPROTO_IP, MRT_PIM, (char *)&v, sizeof(int)) < 0)
-        logit(LOG_ERR, errno, "cannot set PIM flag in kernel");
+        logit(LOG_ERR, errno, "Cannot set PIM flag in kernel");
 }
 
 
@@ -76,10 +80,10 @@ void k_stop_pim(int socket)
     int v = 0;
 
     if (setsockopt(socket, IPPROTO_IP, MRT_PIM, (char *)&v, sizeof(int)) < 0)
-        logit(LOG_ERR, errno, "cannot reset PIM flag in kernel");
+        logit(LOG_ERR, errno, "Cannot reset PIM flag in kernel");
 
     if (setsockopt(socket, IPPROTO_IP, MRT_DONE, (char *)NULL, 0) < 0)
-        logit(LOG_ERR, errno, "cannot disable multicast routing in kernel");
+        logit(LOG_ERR, errno, "Cannot disable multicast routing in kernel");
 }
 
 
@@ -119,9 +123,10 @@ void k_set_sndbuf(int socket, int bufsize, int minsize)
             /*NOTREACHED*/
         }
     }
-    IF_DEBUG(DEBUG_KERN)
+    IF_DEBUG(DEBUG_KERN) {
         logit(LOG_DEBUG, 0, "Got %d byte send buffer size in %d iterations",
               bufsize, iter);
+    }
 }
 
 
@@ -160,9 +165,10 @@ void k_set_rcvbuf(int socket, int bufsize, int minsize)
             /*NOTREACHED*/
         }
     }
-    IF_DEBUG(DEBUG_KERN)
+    IF_DEBUG(DEBUG_KERN) {
         logit(LOG_DEBUG, 0, "Got %d byte recv buffer size in %d iterations",
               bufsize, iter);
+    }
 }
 
 
@@ -178,7 +184,8 @@ void k_hdr_include(int socket, int bool)
 {
 #ifdef IP_HDRINCL
     if (setsockopt(socket, IPPROTO_IP, IP_HDRINCL, (char *)&bool, sizeof(bool)) < 0)
-        logit(LOG_ERR, errno, "setsockopt IP_HDRINCL %u", bool);
+        logit(LOG_ERR, errno, "Failed %s IP_HDRINCL on socket %d",
+	      ENABLINGSTR(bool), socket);
 #endif
 }
 
@@ -197,7 +204,7 @@ void k_set_ttl(int socket __attribute__((unused)), int t)
 
     ttl = t;
     if (setsockopt(socket, IPPROTO_IP, IP_MULTICAST_TTL, (char *)&ttl, sizeof(ttl)) < 0)
-        logit(LOG_ERR, errno, "setsockopt IP_MULTICAST_TTL %u", ttl);
+        logit(LOG_ERR, errno, "Failed setting IP_MULTICAST_TTL %u on socket %d", ttl, socket);
 #endif
 }
 
@@ -211,7 +218,8 @@ void k_set_loop(int socket, int flag)
 
     loop = flag;
     if (setsockopt(socket, IPPROTO_IP, IP_MULTICAST_LOOP, (char *)&loop, sizeof(loop)) < 0)
-        logit(LOG_ERR, errno, "setsockopt IP_MULTICAST_LOOP %u", loop);
+        logit(LOG_ERR, errno, "Failed %s IP_MULTICAST_LOOP on socket %d",
+	      ENABLINGSTR(flag), socket);
 }
 
 
@@ -226,8 +234,8 @@ void k_set_if(int socket, u_int32 ifa)
     if (setsockopt(socket, IPPROTO_IP, IP_MULTICAST_IF, (char *)&adr, sizeof(adr)) < 0) {
         if (errno == EADDRNOTAVAIL || errno == EINVAL)
             return;
-        logit(LOG_ERR, errno, "setsockopt IP_MULTICAST_IF %s",
-              inet_fmt(ifa, s1, sizeof(s1)));
+        logit(LOG_ERR, errno, "Failed setting IP_MULTICAST_IF option on %s",
+              inet_fmt(adr.s_addr, s1, sizeof(s1)));
     }
 }
 
@@ -255,11 +263,11 @@ void k_join(int socket, u_int32 grp, struct uvif *v)
                    (char *)&mreq, sizeof(mreq)) < 0) {
 #ifdef __linux__
         logit(LOG_WARNING, errno,
-              "cannot join group %s on interface %s (ifindex %d)",
+              "Cannot join group %s on interface %s (ifindex %d)",
               inet_fmt(grp, s1, sizeof(s1)), inet_fmt(v->uv_lcl_addr, s2, sizeof(s2)), v->uv_ifindex);
 #else
         logit(LOG_WARNING, errno,
-              "cannot join group %s on interface %s",
+              "Cannot join group %s on interface %s",
               inet_fmt(grp, s1, sizeof(s1)), inet_fmt(v->uv_lcl_addr, s2, sizeof(s2)));
 #endif /* __linux__ */
     }
@@ -288,16 +296,30 @@ void k_leave(int socket, u_int32 grp, struct uvif *v)
     if (setsockopt(socket, IPPROTO_IP, IP_DROP_MEMBERSHIP, (char *)&mreq, sizeof(mreq)) < 0) {
 #ifdef __linux__
         logit(LOG_WARNING, errno,
-              "cannot leave group %s on interface %s (ifindex %d)",
+              "Cannot leave group %s on interface %s (ifindex %d)",
               inet_fmt(grp, s1, sizeof(s1)), inet_fmt(v->uv_lcl_addr, s2, sizeof(s2)), v->uv_ifindex);
 #else
         logit(LOG_WARNING, errno,
-              "cannot leave group %s on interface %s",
+              "Cannot leave group %s on interface %s",
               inet_fmt(grp, s1, sizeof(s1)), inet_fmt(v->uv_lcl_addr, s2, sizeof(s2)));
 #endif /* __linux__ */
     }
 }
 
+/*
+ * Fill struct vifctl using corresponding fields from struct uvif.
+ */
+static void uvif_to_vifctl(struct vifctl *vc, struct uvif *v)
+{
+    /* XXX: we don't support VIFF_TUNNEL; VIFF_SRCRT is obsolete */
+    vc->vifc_flags           = 0;
+    if (v->uv_flags & VIFF_REGISTER)
+        vc->vifc_flags      |= VIFF_REGISTER;
+    vc->vifc_threshold       = v->uv_threshold;
+    vc->vifc_rate_limit      = v->uv_rate_limit;
+    vc->vifc_lcl_addr.s_addr = v->uv_lcl_addr;
+    vc->vifc_rmt_addr.s_addr = v->uv_rmt_addr;
+}
 
 /*
  * Add a virtual interface in the kernel.
@@ -306,31 +328,39 @@ void k_add_vif(int socket, vifi_t vifi, struct uvif *v)
 {
     struct vifctl vc;
 
-    vc.vifc_vifi            = vifi;
-    /* XXX: we don't support VIFF_TUNNEL; VIFF_SRCRT is obsolete */
-    vc.vifc_flags           = 0;
-    if (v->uv_flags & VIFF_REGISTER)
-        vc.vifc_flags       |= VIFF_REGISTER;
-    vc.vifc_threshold       = v->uv_threshold;
-    vc.vifc_rate_limit      = v->uv_rate_limit;
-    vc.vifc_lcl_addr.s_addr = v->uv_lcl_addr;
-    vc.vifc_rmt_addr.s_addr = v->uv_rmt_addr;
-
+    vc.vifc_vifi = vifi;
+    uvif_to_vifctl(&vc, v);
     if (setsockopt(socket, IPPROTO_IP, MRT_ADD_VIF, (char *)&vc, sizeof(vc)) < 0)
-        logit(LOG_ERR, errno, "setsockopt MRT_ADD_VIF on vif %d", vifi);
+        logit(LOG_ERR, errno, "Failed adding VIF %d (MRT_ADD_VIF)", vifi);
 }
 
 
 /*
  * Delete a virtual interface in the kernel.
  */
-void k_del_vif(int socket, vifi_t vifi)
+void k_del_vif(int socket, vifi_t vifi, struct uvif *v __attribute__((unused)))
 {
-    if (setsockopt(socket, IPPROTO_IP, MRT_DEL_VIF,
-                   (char *)&vifi, sizeof(vifi)) < 0) {
+    /*
+     * Unfortunately Linux MRT_DEL_VIF API differs a bit from the *BSD one.  It
+     * expects to receive a pointer to struct vifctl that corresponds to the VIF
+     * we're going to delete.  *BSD systems on the other hand exepect only the
+     * index of that VIF.
+     */
+#ifdef __linux__
+    struct vifctl vc;
+
+    vc.vifc_vifi = vifi;
+    uvif_to_vifctl(&vc, v);	       /* 'v' is used only on Linux systems. */
+
+    if (setsockopt(socket, IPPROTO_IP, MRT_DEL_VIF, (char *)&vc, sizeof(vc)) < 0)
+#else /* *BSD et al. */
+    if (setsockopt(socket, IPPROTO_IP, MRT_DEL_VIF, (char *)&vifi, sizeof(vifi)) < 0)
+#endif /* !__linux__ */
+    {
         if (errno == EADDRNOTAVAIL || errno == EINVAL)
             return;
-        logit(LOG_ERR, errno, "setsockopt MRT_DEL_VIF on vif %d", vifi);
+
+        logit(LOG_ERR, errno, "Failed removing VIF %d (MRT_DEL_VIF)", vifi);
     }
 }
 
@@ -346,13 +376,15 @@ int k_del_mfc(int socket, u_int32 source, u_int32 group)
     mc.mfcc_mcastgrp.s_addr = group;
 
     if (setsockopt(socket, IPPROTO_IP, MRT_DEL_MFC, (char *)&mc, sizeof(mc)) < 0) {
-        logit(LOG_WARNING, errno, "setsockopt k_del_mfc");
+        logit(LOG_WARNING, errno, "Failed removing MFC entry src %s, grp %s",
+              inet_fmt(mc.mfcc_origin.s_addr, s1, sizeof(s1)),
+              inet_fmt(mc.mfcc_mcastgrp.s_addr, s2, sizeof(s2)));
 
         return FALSE;
     }
 
     IF_DEBUG(DEBUG_MFC) {
-        logit(LOG_DEBUG, 0, "Deleted MFC entry: src %s, grp %s",
+        logit(LOG_DEBUG, 0, "Removed MFC entry src %s, grp %s",
               inet_fmt(mc.mfcc_origin.s_addr, s1, sizeof(s1)),
               inet_fmt(mc.mfcc_mcastgrp.s_addr, s2, sizeof(s2)));
     }
@@ -393,8 +425,9 @@ int k_chg_mfc(int socket, u_int32 source, u_int32 group, vifi_t iif, vifbitmap_t
     mc.mfcc_rp_addr.s_addr = rp_addr;
 #endif
     if (setsockopt(socket, IPPROTO_IP, MRT_ADD_MFC, (char *)&mc, sizeof(mc)) < 0) {
-        logit(LOG_WARNING, errno, "setsockopt MRT_ADD_MFC for source %s and group %s",
-              inet_fmt(source, s1, sizeof(s1)), inet_fmt(group, s2, sizeof(s2)));
+        logit(LOG_WARNING, errno, "Failed adding MFC entry src %s grp %s",
+              inet_fmt(mc.mfcc_origin.s_addr, s1, sizeof(s1)),
+	      inet_fmt(mc.mfcc_mcastgrp.s_addr, s2, sizeof(s2)));
 
         return FALSE;
     }
@@ -413,7 +446,7 @@ int k_get_vif_count(vifi_t vifi, struct vif_count *retval)
 
     vreq.vifi = vifi;
     if (ioctl(udp_socket, SIOCGETVIFCNT, (char *)&vreq) < 0) {
-        logit(LOG_WARNING, errno, "SIOCGETVIFCNT on vif %d", vifi);
+        logit(LOG_WARNING, errno, "Failed reading kernel packet count (SIOCGETVIFCNT) on vif %d", vifi);
 
         retval->icount =
             retval->ocount =
@@ -447,7 +480,7 @@ int k_get_sg_cnt(int socket, u_int32 source, u_int32 group, struct sg_count *ret
          * the return code is always 0, so this is why we need to check
          * the wrong_if value.
          */
-        logit(LOG_WARNING, errno, "SIOCGETSGCNT on (%s %s)",
+        logit(LOG_WARNING, errno, "Failed reading kernel count (SIOCGETSGCNT) for (S,G) on (%s, %s)",
               inet_fmt(source, s1, sizeof(s1)), inet_fmt(group, s2, sizeof(s2)));
         retval->pktcnt = retval->bytecnt = retval->wrong_if = ~0;
 
