@@ -49,19 +49,15 @@ vifi_t		numvifs;	/* Number of vifs in use                    */
 int             vifs_down;      /* 1=>some interfaces are down              */
 int             phys_vif;       /* An enabled vif                           */
 vifi_t		reg_vif_num;    /* really virtual interface for registers   */
-int		udp_socket;	/* Since the honkin' kernel doesn't support */
-				/* ioctls on raw IP sockets, we need a UDP  */
-				/* socket as well as our IGMP (raw) socket. */
-				/* How dumb.                                */
+int		udp_socket;	/* Since the honkin' kernel doesn't support
+				 * ioctls on raw IP sockets, we need a UDP
+				 * socket as well as our IGMP (raw) socket. */
 int             total_interfaces; /* Number of all interfaces: including the
 				   * non-configured, but excluding the
 				   * loopback interface and the non-multicast
 				   * capable interfaces.
 				   */
 
-/*
- * Forward declarations.
- */
 static void start_vif      (vifi_t vifi);
 static void stop_vif       (vifi_t vifi);
 static void start_all_vifs (void);
@@ -74,17 +70,14 @@ void init_vifs(void)
     vifi_t vifi;
     struct uvif *v;
     int enabled_vifs;
-	
+
     numvifs    = 0;
     reg_vif_num = NO_VIF;
     vifs_down = FALSE;
 
-    /*
-     * Configure the vifs based on the interface configuration of the
-     * the kernel and the contents of the configuration file.
-     * (Open a UDP socket for ioctl use in the config procedures if
-     * the kernel can't handle IOCTL's on the IGMP socket.)
-     */
+    /* Configure the vifs based on the interface configuration of the the kernel and
+     * the contents of the configuration file.  (Open a UDP socket for ioctl use in
+     * the config procedures if the kernel can't handle IOCTL's on the IGMP socket.) */
 #ifdef IOCTL_OK_ON_RAW_SOCKET
     udp_socket = igmp_socket;
 #else
@@ -92,9 +85,7 @@ void init_vifs(void)
 	logit(LOG_ERR, errno, "UDP socket");
 #endif
 
-    /*
-     * Clean up all vifs
-     */
+    /* Clean up all vifs */
     for (vifi = 0, v = uvifs; vifi < MAXVIFS; ++vifi, ++v) {
 	zero_vif(v, FALSE);
     }
@@ -103,6 +94,7 @@ void init_vifs(void)
     config_vifs_from_kernel();
     if (disable_all_by_default) {
        logit(LOG_INFO, 0, "Disabling all vifs from kernel");
+
        for (vifi = 0, v = uvifs; vifi < numvifs; ++vifi, ++v)
           v->uv_flags |= VIFF_DISABLED;
     }
@@ -114,30 +106,28 @@ void init_vifs(void)
      */
     enabled_vifs    = 0;
     phys_vif        = -1;
-	 
+
     for (vifi = 0, v = uvifs; vifi < numvifs; ++vifi, ++v) {
-	/* Initialize the outgoing timeout for each vif.
-	 * Currently use a fixed time 'PIM_JOIN_PRUNE_HOLDTIME'.
-	 * Later, may add a configurable array to feed these
-	 * parameters, or compute them as function of the i/f
-	 * bandwidth and the overall connectivity...etc.
-	 */
+	/* Initialize the outgoing timeout for each vif.  Currently use a fixed time
+	 * 'PIM_JOIN_PRUNE_HOLDTIME'.  Later, may add a configurable array to feed
+	 * these parameters, or compute them as function of the i/f bandwidth and the
+	 * overall connectivity...etc. */
 	SET_TIMER(v->uv_jp_timer, PIM_JOIN_PRUNE_HOLDTIME);
-	if (v->uv_flags
-	    & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER | VIFF_TUNNEL))
+	if (v->uv_flags & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER | VIFF_TUNNEL))
 	    continue;
+
 	if (phys_vif == -1)
 	    phys_vif = vifi;
+
 	enabled_vifs++;
     }
 
     if (enabled_vifs < 1) /* XXX: TODO: */
-	logit(LOG_ERR, 0, "can't forward: %s",
-	    enabled_vifs == 0 ? "no enabled vifs" : "only one enabled vif");
-    
+	logit(LOG_ERR, 0, "Cannot forward: %s", enabled_vifs == 0 ? "no enabled vifs" : "only one enabled vif");
+
     k_init_pim(igmp_socket);	/* Call to kernel to initialize structures */
 
-    /* Add a dummy virtual interface to support Registers in the kernel. 
+    /* Add a dummy virtual interface to support Registers in the kernel.
      * In order for this to work, the kernel has to have been modified
      * with the PIM patches to ip_mroute.{c,h} and ip.c
      */
@@ -150,10 +140,7 @@ void init_vifs(void)
  * Initialize the passed vif with all appropriate default values.
  * "t" is true if a tunnel or register_vif, or false if a phyint.
  */
-void
-zero_vif(v, t)
-    struct uvif *v;
-    int t;
+void zero_vif(struct uvif *v, int t)
 {
     v->uv_flags		= 0;
     v->uv_metric	= DEFAULT_METRIC;
@@ -196,48 +183,51 @@ static int init_reg_vif(void)
 {
     struct uvif *v;
     vifi_t i;
-    
+
     v = &uvifs[numvifs];
-    v->uv_flags = 0; /* initialization */
+    v->uv_flags = 0;
+
     if ((numvifs + 1) == MAXVIFS) {
         /* Exit the program! The PIM router must have a Register vif */
-	logit(LOG_ERR, 0,
-	    "cannot install the Register vif: too many interfaces");
-	/* To make lint happy */
-	return (FALSE);
+	logit(LOG_ERR, 0, "Cannot install the Register vif: too many interfaces");
+
+	return FALSE;
     }
-    
+
     /*
      * So far in PIM we need only one register vif and we save its number in
      * the global reg_vif_num.
      */
     reg_vif_num = numvifs;
-    
+
     /* set the REGISTER flag */
     v->uv_flags = VIFF_REGISTER;
 #ifdef PIM_EXPERIMENTAL
     v->uv_flags |= VIFF_REGISTER_KERNEL_ENCAP;
 #endif
-    strlcpy(v->uv_name,"register_vif0", IFNAMSIZ);
-    
+    strlcpy(v->uv_name, "register_vif0", sizeof(v->uv_name));
+
     /* Use the address of the first available physical interface to
      * create the register vif.
      */
-    for (i = 0; i < numvifs; i++)
-	if (uvifs[i].uv_flags
-	    & (VIFF_DOWN | VIFF_DISABLED | VIFF_REGISTER | VIFF_TUNNEL))
+    for (i = 0; i < numvifs; i++) {
+	if (uvifs[i].uv_flags & (VIFF_DOWN | VIFF_DISABLED | VIFF_REGISTER | VIFF_TUNNEL))
 	    continue;
-	else
-	    break;
+
+	break;
+    }
+
     if (i >= numvifs) {
 	logit(LOG_ERR, 0, "No physical interface enabled");
 	return -1;
     }
+
     v->uv_lcl_addr = uvifs[i].uv_lcl_addr;
     v->uv_threshold = MINTTL;
 
     numvifs++;
     total_interfaces++;
+
     return 0;
 }
 
@@ -249,44 +239,42 @@ static void start_all_vifs(void)
     u_int action;
 
     /* Start first the NON-REGISTER vifs */
-    for(action = 0; ; action = VIFF_REGISTER) {
+    for (action = 0; ; action = VIFF_REGISTER) {
 	for (vifi = 0, v = uvifs; vifi < numvifs; ++vifi, ++v) {
+	    /* If starting non-registers but the vif is a register or if starting
+	     * registers, but the interface is not a register, then just continue. */
 	    if ((v->uv_flags & VIFF_REGISTER) ^ action)
-		/* If starting non-registers but the vif is a register
-		 * or if starting registers, but the interface is not
-		 * a register, then just continue.
-		 */
 		continue;
+
 	    /* Start vif if not DISABLED or DOWN */
 	    if (v->uv_flags & (VIFF_DISABLED | VIFF_DOWN)) {
 		if (v->uv_flags & VIFF_DISABLED)
-		    logit(LOG_INFO, 0,
-			"%s is DISABLED; vif #%u out of service", 
-			v->uv_name, vifi);
+		    logit(LOG_INFO, 0, "Interface %s is DISABLED; vif #%u out of service", v->uv_name, vifi);
 		else
-		    logit(LOG_INFO, 0,
-			"%s is DOWN; vif #%u out of service", 
-			v->uv_name, vifi);
-	    }
-	    else
+		    logit(LOG_INFO, 0, "Interface %s is DOWN; vif #%u out of service", v->uv_name, vifi);
+	    } else {
 		start_vif(vifi);
+	    }
 	}
+
 	if (action == VIFF_REGISTER)
 	    break;   /* We are done */
     }
 }
 
 
-
 /*
  * stop all vifs
  */
 void stop_all_vifs(void)
 {
     vifi_t vifi;
+    struct uvif *v;
 
     for (vifi = 0; vifi < numvifs; vifi++) {
-	stop_vif(vifi);
+	v = &uvifs[vifi];
+	if (!(v->uv_flags & VIFF_DOWN))
+	    stop_vif(vifi);
     }
 }
 
@@ -299,12 +287,10 @@ void stop_all_vifs(void)
 static void start_vif(vifi_t vifi)
 {
     struct uvif *v;
-    u_int32    src;
 
-    v		    = &uvifs[vifi];
-    src             = v->uv_lcl_addr;
+    v	= &uvifs[vifi];
     /* Initialy no router on any vif */
-    if (v->uv_flags & VIFF_REGISTER) 
+    if (v->uv_flags & VIFF_REGISTER)
 	v->uv_flags = v->uv_flags & ~VIFF_DOWN;
     else {
 	v->uv_flags = (v->uv_flags | VIFF_DR | VIFF_NONBRS) & ~VIFF_DOWN;
@@ -314,24 +300,24 @@ static void start_vif(vifi_t vifi)
 	RESET_TIMER(v->uv_gq_timer);
 	v->uv_pim_neighbors = (pim_nbr_entry_t *)NULL;
     }
-    
+
     /* Tell kernel to add, i.e. start this vif */
-    k_add_vif(igmp_socket, vifi, &uvifs[vifi]);   
-    logit(LOG_INFO, 0, "%s comes up; vif #%u now in service", v->uv_name, vifi);
-    
+    k_add_vif(igmp_socket, vifi, &uvifs[vifi]);
+    logit(LOG_INFO, 0, "Interface %s comes up; vif #%u now in service", v->uv_name, vifi);
+
     if (!(v->uv_flags & VIFF_REGISTER)) {
 	/*
 	 * Join the PIM multicast group on the interface.
 	 */
 	k_join(igmp_socket, allpimrouters_group, v);
-	
+
 	/*
 	 * Join the ALL-ROUTERS multicast group on the interface.
 	 * This allows mtrace requests to loop back if they are run
 	 * on the multicast router.
 	 */
 	k_join(igmp_socket, allrouters_group, v);
-	
+
 	/*
 	 * Until neighbors are discovered, assume responsibility for sending
 	 * periodic group membership queries to the subnet.  Send the first
@@ -339,7 +325,7 @@ static void start_vif(vifi_t vifi)
 	 */
 	v->uv_flags |= VIFF_QUERIER;
 	query_groups(v);
-	
+
 	/*
 	 * Send a probe via the new vif to look for neighbors.
 	 */
@@ -348,7 +334,7 @@ static void start_vif(vifi_t vifi)
 #ifdef __linux__
     else {
 	struct ifreq ifr;
-	
+
 	memset(&ifr, 0, sizeof(struct ifreq));
 	/* strlcpy(ifr.ifr_name,v->uv_name, IFNAMSIZ); */
 	strlcpy(ifr.ifr_name, "pimreg", IFNAMSIZ);
@@ -371,13 +357,13 @@ static void stop_vif(vifi_t vifi)
 {
     struct uvif *v;
     struct listaddr *a;
-    register pim_nbr_entry_t *n, *next;
+    pim_nbr_entry_t *n, *next;
     struct vif_acl *acl;
-    
+
     /*
-     * TODO: make sure that the kernel viftable is 
+     * TODO: make sure that the kernel viftable is
      * consistent with the daemon table
-     */	
+     */
     v = &uvifs[vifi];
     if (!(v->uv_flags & VIFF_REGISTER)) {
 	k_leave(igmp_socket, allpimrouters_group, v);
@@ -392,24 +378,23 @@ static void stop_vif(vifi_t vifi)
 	    free((char *)a);
 	}
     }
-    
+
     /*
      * TODO: inform (eventually) the neighbors I am going down by sending
      * PIM_HELLO with holdtime=0 so someone else should become a DR.
-     */ 
+     */
     /* TODO: dummy! Implement it!! Any problems if don't use it? */
     delete_vif_from_mrt(vifi);
-    
-    /*
-     * Delete the interface from the kernel's vif structure.
-     */
-    k_del_vif(igmp_socket, vifi);
-    v->uv_flags     = (v->uv_flags & ~VIFF_DR & ~VIFF_QUERIER & ~VIFF_NONBRS )
-	              | VIFF_DOWN;
+
+    /* Delete the interface from the kernel's vif structure. */
+    k_del_vif(igmp_socket, vifi, v);
+
+    v->uv_flags = (v->uv_flags & ~VIFF_DR & ~VIFF_QUERIER & ~VIFF_NONBRS) | VIFF_DOWN;
     if (!(v->uv_flags & VIFF_REGISTER)) {
 	RESET_TIMER(v->uv_pim_hello_timer);
 	RESET_TIMER(v->uv_jp_timer);
 	RESET_TIMER(v->uv_gq_timer);
+
 	for (n = v->uv_pim_neighbors; n != NULL; n = next) {
 	    next = n->next;	/* Free the space for each neighbour */
 	    free((char *)n);
@@ -426,9 +411,8 @@ static void stop_vif(vifi_t vifi)
     }
 
     vifs_down = TRUE;
-    logit(LOG_INFO, 0,
-	"%s goes down; vif #%u out of service", v->uv_name, vifi);
-}		
+    logit(LOG_INFO, 0, "Interface %s goes down; vif #%u out of service", v->uv_name, vifi);
+}
 
 
 /*
@@ -440,27 +424,31 @@ static void stop_vif(vifi_t vifi)
  */
 static int update_reg_vif(vifi_t register_vifi)
 {
-    register struct uvif *v;
-    register vifi_t vifi;
+    struct uvif *v;
+    vifi_t vifi;
 
     /* Find the first useable vif with solid physical background */
     for (vifi = 0, v = uvifs; vifi < numvifs; ++vifi, ++v) {
-	if (v->uv_flags
-	    & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER | VIFF_TUNNEL))
+	if (v->uv_flags & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER | VIFF_TUNNEL))
 	    continue;
+
         /* Found. Stop the bogus Register vif first */
 	stop_vif(register_vifi);
 	uvifs[register_vifi].uv_lcl_addr = uvifs[vifi].uv_lcl_addr;
+
 	start_vif(register_vifi);
-	IF_DEBUG(DEBUG_PIM_REGISTER | DEBUG_IF)
-	    logit(LOG_NOTICE, 0, "%s has come up; vif #%u now in service",
-		uvifs[register_vifi].uv_name, register_vifi);
+	IF_DEBUG(DEBUG_PIM_REGISTER | DEBUG_IF) {
+	    logit(LOG_NOTICE, 0, "Interface %s has come up; vif #%u now in service",
+		  uvifs[register_vifi].uv_name, register_vifi);
+	}
+
 	return 0;
     }
+
     vifs_down = TRUE;
-    logit(LOG_WARNING, 0, "Cannot start Register vif: %s",
-	uvifs[vifi].uv_name);
-    return(-1);
+    logit(LOG_WARNING, 0, "Cannot start Register vif: %s", uvifs[vifi].uv_name);
+
+    return -1;
 }
 
 
@@ -472,8 +460,8 @@ static int update_reg_vif(vifi_t register_vifi)
  */
 void check_vif_state(void)
 {
-    register vifi_t vifi;
-    register struct uvif *v;
+    vifi_t vifi;
+    struct uvif *v;
     struct ifreq ifr;
     static int checking_vifs = 0;
 
@@ -488,75 +476,70 @@ void check_vif_state(void)
 
     vifs_down = FALSE;
     checking_vifs = 1;
+
     /* TODO: Check all potential interfaces!!! */
     /* Check the physical and tunnels only */
     for (vifi = 0, v = uvifs; vifi < numvifs; ++vifi, ++v) {
 	if (v->uv_flags & (VIFF_DISABLED | VIFF_REGISTER))
 	    continue;
-	
-	strlcpy(ifr.ifr_name, v->uv_name, IFNAMSIZ);
+
 	/* get the interface flags */
+	strlcpy(ifr.ifr_name, v->uv_name, sizeof(ifr.ifr_name));
 	if (ioctl(udp_socket, SIOCGIFFLAGS, (char *)&ifr) < 0) {
            if (errno == ENODEV) {
-              logit(LOG_NOTICE, 0, "%s has gone; vif #%u taken out of service",
-                       v->uv_name, vifi);
+              logit(LOG_NOTICE, 0, "Interface %s has gone; vif #%u taken out of service", v->uv_name, vifi);
               stop_vif(vifi);
               vifs_down = TRUE;
               continue;
            }
-           else {
-              logit(LOG_ERR, errno,
-                       "check_vif_state: ioctl SIOCGIFFLAGS for %s", ifr.ifr_name);
-           }
+
+	   logit(LOG_ERR, errno, "check_vif_state: ioctl SIOCGIFFLAGS for %s", ifr.ifr_name);
 	}
 
 	if (v->uv_flags & VIFF_DOWN) {
-	    if (ifr.ifr_flags & IFF_UP) {
+	    if (ifr.ifr_flags & IFF_UP)
 		start_vif(vifi);
-	    }
-	    else vifs_down = TRUE;
-	}
-	else {
+	    else
+		vifs_down = TRUE;
+	} else {
 	    if (!(ifr.ifr_flags & IFF_UP)) {
-		logit(LOG_NOTICE, 0,
-		    "%s has gone down; vif #%u taken out of service",
-		    v->uv_name, vifi);
+		logit(LOG_NOTICE, 0, "Interface %s has gone down; vif #%u taken out of service", v->uv_name, vifi);
 		stop_vif(vifi);
 		vifs_down = TRUE;
 	    }
 	}
     }
+
     /* Check the register(s) vif(s) */
     for (vifi = 0, v = uvifs; vifi < numvifs; ++vifi, ++v) {
-	register vifi_t vifi2;
-	register struct uvif *v2;
+	vifi_t vifi2;
+	struct uvif *v2;
 	int found;
-	
+
 	if (!(v->uv_flags & VIFF_REGISTER))
 	    continue;
-	else {
-	    found = 0;
-	    /* Find a physical vif with the same IP address as the
-	     * Register vif.
-	     */
-	    for (vifi2 = 0, v2 = uvifs; vifi2 < numvifs; ++vifi2, ++v2) {
-		if (v2->uv_flags
-		    & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER | VIFF_TUNNEL))
-		    continue;
-		if (v->uv_lcl_addr != v2->uv_lcl_addr)
-		    continue;
-		else {
-		    found = 1;
-		    break;
-		}
-	    }
-	    if (!found)
-		/* The physical interface with the IP address as the Register
-		 * vif is probably DOWN. Get a replacement.
-		 */
-		update_reg_vif(vifi);
+
+	found = 0;
+
+	/* Find a physical vif with the same IP address as the
+	 * Register vif. */
+	for (vifi2 = 0, v2 = uvifs; vifi2 < numvifs; ++vifi2, ++v2) {
+	    if (v2->uv_flags & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER | VIFF_TUNNEL))
+		continue;
+
+	    if (v->uv_lcl_addr != v2->uv_lcl_addr)
+		continue;
+
+	    found = 1;
+	    break;
 	}
+
+	/* The physical interface with the IP address as the Register
+	 * vif is probably DOWN. Get a replacement. */
+	if (!found)
+	    update_reg_vif(vifi);
     }
+
     checking_vifs = 0;
 }
 
@@ -570,34 +553,37 @@ void check_vif_state(void)
 vifi_t find_vif_direct(u_int32 src)
 {
     vifi_t vifi;
-    register struct uvif *v;
-    register struct phaddr *p;
-	
+    struct uvif *v;
+    struct phaddr *p;
+
     for (vifi = 0, v = uvifs; vifi < numvifs; ++vifi, ++v) {
-	if (v->uv_flags
-	    & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER | VIFF_TUNNEL))
+	if (v->uv_flags & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER | VIFF_TUNNEL))
 	    continue;
+
 	if (src == v->uv_lcl_addr)
-	    return (NO_VIF);     /* src is one of our IP addresses */
-	if ((src & v->uv_subnetmask) == v->uv_subnet && 
+	    return NO_VIF;	/* src is one of our IP addresses */
+
+	if ((src & v->uv_subnetmask) == v->uv_subnet &&
 	    ((v->uv_subnetmask == 0xffffffff) ||
 	     (src != v->uv_subnetbcast)))
-	    return(vifi);
+	    return vifi;
+
 	/* Check the extra subnets for this vif */
 	/* TODO: don't think currently pimd can handle extra subnets */
 	for (p = v->uv_addrs; p; p = p->pa_next) {
 	    if ((src & p->pa_subnetmask) == p->pa_subnet &&
 		((p->pa_subnetmask == 0xffffffff) ||
 		 (src != p->pa_subnetbcast)))
-		return(vifi);
+		return vifi;
 	}
+
 	/* POINTOPOINT but not VIFF_TUNNEL interface (e.g., GRE) */
-	if ((v->uv_flags & VIFF_POINT_TO_POINT)
-	    && (src == v->uv_rmt_addr))
-	    return (vifi);
+	if ((v->uv_flags & VIFF_POINT_TO_POINT) && (src == v->uv_rmt_addr))
+	    return vifi;
     }
-    return (NO_VIF);
-} 
+
+    return NO_VIF;
+}
 
 
 /*
@@ -607,20 +593,21 @@ vifi_t find_vif_direct(u_int32 src)
 vifi_t local_address(u_int32 src)
 {
     vifi_t vifi;
-    register struct uvif *v;
-    
+    struct uvif *v;
+
     for (vifi = 0, v = uvifs; vifi < numvifs; ++vifi, ++v) {
 	/* TODO: XXX: what about VIFF_TUNNEL? */
-	if (v->uv_flags
-	    & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER))
+	if (v->uv_flags & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER))
 	    continue;
+
 	if (src != v->uv_lcl_addr)
 	    continue;
-	else 
-	    return(vifi);
-    }   
+	else
+	    return vifi;
+    }
+
     /* Returning NO_VIF means not a local address */
-    return (NO_VIF);	
+    return NO_VIF;
 }
 
 /*
@@ -632,35 +619,37 @@ vifi_t local_address(u_int32 src)
 vifi_t find_vif_direct_local(u_int32 src)
 {
     vifi_t vifi;
-    register struct uvif *v;
-    register struct phaddr *p;
-    
+    struct uvif *v;
+    struct phaddr *p;
+
     for (vifi = 0, v = uvifs; vifi < numvifs; ++vifi, ++v) {
 	/* TODO: XXX: what about VIFF_TUNNEL? */
-	if (v->uv_flags &
-	    (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER | VIFF_TUNNEL))
+	if (v->uv_flags & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER | VIFF_TUNNEL))
 	    continue;
+
 	if (src == v->uv_lcl_addr)
-	    return (vifi);     /* src is one of our IP addresses */
+	    return vifi;	/* src is one of our IP addresses */
+
 	if (((src & v->uv_subnetmask) == v->uv_subnet)
 	    && ((v->uv_subnetmask == 0xffffffff)
 		|| (src != v->uv_subnetbcast)))
-	    return(vifi);
+	    return vifi;
+
 	/* Check the extra subnets for this vif */
 	/* TODO: don't think currently pimd can handle extra subnets */
 	for (p = v->uv_addrs; p; p = p->pa_next) {
 	    if (((src & p->pa_subnetmask) == p->pa_subnet)
 		&& ((p->pa_subnetmask == 0xffffffff)
 		    || (src != p->pa_subnetbcast)))
-		return(vifi);
+		return vifi;
 	}
+
 	/* POINTOPOINT but not VIFF_TUNNEL interface (e.g., GRE) */
-	if ((v->uv_flags & VIFF_POINT_TO_POINT)
-	    && (src == v->uv_rmt_addr))
-	    return (vifi);
+	if ((v->uv_flags & VIFF_POINT_TO_POINT) && (src == v->uv_rmt_addr))
+	    return vifi;
     }
-    return (NO_VIF);
-} 
+    return NO_VIF;
+}
 
 /*
  * Returns the highest address of local vif that is UP and ENABLED.
@@ -671,16 +660,18 @@ u_int32 max_local_address(void)
     vifi_t vifi;
     struct uvif *v;
     u_int32 max_address = 0;
-    
+
     for (vifi = 0, v = uvifs; vifi < numvifs; ++vifi, ++v) {
 	/* Count vif if not DISABLED or DOWN */
 	/* TODO: XXX: What about VIFF_TUNNEL? */
 	if (v->uv_flags & (VIFF_DISABLED | VIFF_DOWN | VIFF_REGISTER))
 	    continue;
+
 	if (ntohl(v->uv_lcl_addr) > ntohl(max_address))
 	    max_address = v->uv_lcl_addr;
     }
-    return(max_address);
+
+    return max_address;
 }
 
 /**
